@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2011 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2014 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -50,7 +50,7 @@ STATUSDB = os.path.join(DPKGLIB, 'status')
 # Headers other than these become email headers for debbugs servers
 PSEUDOHEADERS = ('Package', 'Source', 'Version', 'Severity', 'File', 'Tags',
                  'Justification', 'Followup-For', 'Owner', 'User', 'Usertags',
-                 'Forwarded')
+                 'Forwarded', 'Control')
 
 MODES = {'novice': 'Offer simple prompts, bypassing technical questions.',
          'standard': 'Offer more extensive prompts, including asking about '
@@ -74,7 +74,8 @@ import ui.text_ui as ui
 from reportbug.ui import AVAILABLE_UIS
 
 NEWBIELINE = """Dear Maintainer,
-*** Please consider answering these questions, where appropriate ***
+
+*** Reporter, please consider answering these questions, where appropriate ***
 
    * What led up to the situation?
    * What exactly did you do (or not do) that was effective (or
@@ -82,15 +83,15 @@ NEWBIELINE = """Dear Maintainer,
    * What was the outcome of this action?
    * What outcome did you expect instead?
 
-*** End of the template - remove these lines ***"""
+*** End of the template - remove these template lines ***"""
 
 fhs_directories = ['/', '/usr', '/usr/share', '/var', '/usr/X11R6',
                    '/usr/man', '/usr/doc', '/usr/bin']
 
 # A map between suites and distributions names
-SUITES2DISTS = {'lenny': 'oldstable',
-                'squeeze': 'stable',
-                'wheezy': 'testing',
+SUITES2DISTS = {'squeeze': 'oldstable',
+                'wheezy': 'stable',
+                'jessie': 'testing',
                 'sid': 'unstable',
                 'experimental': 'experimental'}
 
@@ -180,7 +181,7 @@ def query_dpkg_for(filename, use_dlocate=True):
         # Ignore diversions
         if 'diversion by' in line: continue
 
-        (package, path) = line.split(':', 1)
+        (package, path) = line.split(': ', 1)
         path = path.strip()
         packlist = package.split(', ')
         for package in packlist:
@@ -497,7 +498,7 @@ def get_avail_database():
 def available_package_description(package):
     data = commands.getoutput('apt-cache show'+commands.mkarg(package))
     data = data.decode('utf-8', 'replace')
-    descre = re.compile(r'^Description: (.*)$')
+    descre = re.compile(r'^Description(?:-en): (.*)$')
     for line in data.split('\n'):
         m = descre.match(line)
         if m:
@@ -652,7 +653,7 @@ def get_dependency_info(package, depends, rel="depends on"):
     for (pack, status, vers, desc, provides) in deplist:
         if provides:
             pack += ' [' + provides + ']'
-        deplist2.append((pack, vers))
+        deplist2.append((pack, vers, status))
     deplist = deplist2
 
     # now we can compute the max possible value for each column, that can be the
@@ -664,7 +665,7 @@ def get_dependency_info(package, depends, rel="depends on"):
     widthp = min(maxp, 73-maxv)
     widthv = min(maxv, 73-widthp)
 
-    for (pack, vers) in deplist:
+    for (pack, vers, status) in deplist:
         # we format the string specifying to align it in a field of a given
         # dimension (the first {width*}) but also limit its size (the second
         # {width*}
@@ -762,6 +763,9 @@ def get_arch():
         arch = re.sub(r'ppc', 'powerpc', arch)
     return arch
 
+def get_multiarch():
+    return commands.getoutput('COLUMNS=79 dpkg --print-foreign-architectures 2>/dev/null')
+
 def generate_blank_report(package, pkgversion, severity, justification,
                           depinfo, confinfo, foundfile='', incfiles='',
                           system='debian', exinfo=None, type=None, klass='',
@@ -856,7 +860,7 @@ MUA = {
     'mutt' : Mua('mutt -H'),
     'mh' : Mua('/usr/bin/mh/comp -use -file'),
     'gnus' : Gnus(),
-    'claws-mail' : Mua('claws-mail --compose-read'),
+    'claws-mail' : Mua('claws-mail --compose-from-file'),
     }
 MUA['nmh'] = MUA['mh']
 
@@ -878,6 +882,8 @@ def mua_is_supported(mua):
         mua_tmp = 'gnus'
     elif mua == 'mutt' or mua == MUA['mutt']:
         mua_tmp = 'mutt'
+    elif mua == 'claws-mail' or mua == MUA['claws-mail']:
+        mua_tmp = 'claws-mail'
     else:
         mua_tmp = mua
     if mua_tmp not in MUA:
@@ -895,6 +901,8 @@ def mua_exists(mua):
         mua_tmp = MUA['gnus']
     elif mua == 'mutt' or mua == MUA['mutt']:
         mua_tmp = MUA['mutt']
+    elif mua == 'claws-mail' or mua == MUA['claws-mail']:
+        mua_tmp = MUA['claws-mail']
     else:
         mua_tmp = MUA[mua]
     output = '/dev/null'
@@ -1174,7 +1182,9 @@ def exec_and_parse_bugscript(handler, bugscript):
 
     isheaders = False
     ispseudoheaders = False
+    isattachments = False
     headers = pseudoheaders = text = ''
+    attachments = []
     fp = open(filename)
     for line in fp.readlines():
         # we identify the blocks for headers and pseudo-h
@@ -1186,15 +1196,31 @@ def exec_and_parse_bugscript(handler, bugscript):
             ispseudoheaders = True
         elif line == '-- END PSEUDOHEADERS --\n':
             ispseudoheaders = False
+        elif line == '-- BEGIN ATTACHMENTS --\n':
+            isattachments = True
+        elif line == '-- END ATTACHMENTS --\n':
+            isattachments = False
         else:
             if isheaders:
                 headers += line
             elif ispseudoheaders:
                 pseudoheaders += line
+            elif isattachments:
+                attachments.append(line.strip())
             else:
                 text += line
     fp.close()
     cleanup_temp_file(filename)
 
     text = text.decode('utf-8', 'replace')
-    return (rc, headers, pseudoheaders, text)
+    return (rc, headers, pseudoheaders, text, attachments)
+
+def check_package_name(pkg):
+    """Check the package name against Debian Policy:
+    https://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-Source
+
+    Returns True if the package name is valid."""
+
+    pkg_re = re.compile('^[a-z0-9][a-z0-9+-\.]+$')
+
+    return True if pkg_re.match(pkg) else False
