@@ -2,6 +2,9 @@ import unittest2
 
 from reportbug import utils
 import os.path
+import platform
+from nose.plugins.attrib import attr
+import debianbts
 
 class TestUtils(unittest2.TestCase):
 
@@ -255,24 +258,30 @@ class TestSystemInformation(unittest2.TestCase):
         res = utils.lsb_release_info()
         self.assertIn('Debian', res)
 
+    def test_get_running_kernel_pkg(self):
+
+        package = utils.get_running_kernel_pkg()
+
+        self.assertIn(platform.release(), package)
+
 class TestMua(unittest2.TestCase):
 
     def test_mua_is_supported(self):
 
-        for mua in ('mh', 'nmh', 'gnus', 'mutt'):
+        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
             self.assertTrue(utils.mua_is_supported(mua))
 
         self.assertFalse(utils.mua_is_supported('mua-of-my-dreams'))
 
     def test_mua_exists(self):
 
-        for mua in ('mh', 'nmh', 'gnus', 'mutt'):
+        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
             if not utils.mua_exists(mua):
                 self.fail("%s MUA program not available" % mua)
 
     def test_mua_name(self):
 
-        for mua in ('mh', 'nmh', 'gnus', 'mutt'):
+        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
             self.assertIsInstance(utils.mua_name(mua), utils.Mua)
 
         self.assertEqual(utils.mua_name('mua-of-my-dreams'), 'mua-of-my-dreams')
@@ -294,6 +303,29 @@ class TestBugreportBody(unittest2.TestCase):
         result = utils.get_dependency_info('reportbug', [['awk']])
         self.assertIn('awk', result)
 
+
+    def test_bts657753(self):
+        # check that non-existing deps gets a correct installation info
+        # and not just the last one applied to anyone
+        result = utils.get_dependency_info('reportbug',
+                                           (('reportbug',), ('nonexisting',)))
+        for line in result.split('\n'):
+            if 'nonexisting' in line:
+                self.assertFalse(line.startswith('ii'))
+
+    def test_bts650659(self):
+        # verify that the dependency list doesn't have tailing white spaces
+
+        status = utils.get_package_status('reportbug')
+        (pkgversion, pkgavail, depends, recommends, conffiles, maintainer,
+         installed, origin, vendor, reportinfo, priority, desc, src_name,
+         fulldesc, state, suggests, section) = status
+
+        for l in [depends, recommends, suggests]:
+            result = utils.get_dependency_info('reportbug', l)
+            for line in result.split('\n'):
+                self.assertEqual(line.rstrip(), line)
+
     def test_cleanup_msg(self):
 
         message = """Subject: unblock: reportbug/4.12.6
@@ -344,6 +376,7 @@ Shell: /bin/sh linked to /bin/bash"""
         self.assertIn('Morph', p)
 
 
+    @attr('network') #marking the test as using network
     def test_generate_blank_report(self):
 
         report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
@@ -353,6 +386,11 @@ Shell: /bin/sh linked to /bin/bash"""
         self.assertIn('Version: 1.2.3', report)
         self.assertIn('Severity: normal', report)
 
+        report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
+                                             '', '', '', type='debbugs',
+                                             issource=True)
+        self.assertIn('Source: reportbug', report)
+
         # test with exinfo (represents the bug number if this is a followup):
         # int, string, unconvertible (to int) datatype
         report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
@@ -360,9 +398,10 @@ Shell: /bin/sh linked to /bin/bash"""
                                              exinfo=123456)
         self.assertIn('Followup-For: Bug #123456', report)
 
+        bug = debianbts.get_status(123456)[0]
         report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
                                              '', '', '', type='debbugs',
-                                             exinfo='123456')
+                                             exinfo=bug)
         self.assertIn('Followup-For: Bug #123456', report)
 
         with self.assertRaises(TypeError):
@@ -372,19 +411,67 @@ Shell: /bin/sh linked to /bin/bash"""
 
 class TestConfig(unittest2.TestCase):
 
-# Find a way to specify an "internal" file for testing
-#    def setUp(self):
-#        self._FILES = utils.FILES
-#        utils.FILES = os.path.dirname(__file__) + '/data/reportbugrc'
-#
-#    def tearDown(self):
-#        utils.FILES = self._FILES
-#
-# --> check the code in utils.parse_config_files to get all the checked params
+    # Use an "internal" file for testing
+    def setUp(self):
+        self._FILES = utils.FILES
+        utils.FILES = [os.path.dirname(__file__) + '/data/reportbug.conf']
+
+    def tearDown(self):
+        utils.FILES = self._FILES
 
     def test_parse_config_files(self):
+
+        desired_conf = {
+            'bts': 'debian',
+            'check_available': True,
+            'check_uid': False,
+            'debconf': False,
+            'dontquery': False,
+            'editor': u'emacs -nw',
+            'email': u'reportbug-maint@lists.alioth.debian.org',
+            'envelopefrom': u'reportbug-maint@lists.alioth.debian.org',
+            'headers': ['X-Reportbug-Testsuite: this is the test suite'],
+            'http_proxy': u'http://proxy.example.com:3128/',
+            'interface': 'gtk2',
+            'keyid': u'deadbeef',
+            'max_attachment_size': 1024000,
+            'mbox_reader_cmd': u'mutt -f %s',
+            'mirrors': ['this_is_a_bts_mirror'],
+            'mode': 'novice',
+            'mta': u'/usr/sbin/sendmail',
+            'nocc': False,
+            'nocompress': False,
+            'noconf': False,
+            'offline': True,
+            'paranoid': True,
+            'query_src': False,
+            'realname': u'Reportbug Maintainers',
+            'replyto': u'We dont care <dev@null.org>',
+            'sendto': 'submit',
+            'severity': 'normal',
+            'sign': 'gpg',
+            'smtphost': u'reportbug.debian.org:587',
+            'smtppasswd': u'James Bond',
+            'smtptls': True,
+            'smtpuser': u'Bond',
+            'template': True,
+            'verify': True}
+
         args = utils.parse_config_files()
-        self.assertIsNot(args, {})
+        for conf in desired_conf:
+            self.assertIn(conf, args)
+            self.assertEqual(desired_conf[conf], args[conf])
+
+        # mua returns an instance of utils.Mua, need to check differently
+        self.assertIn('mua', args)
+        self.assertIsInstance(args['mua'], utils.Mua)
+
+    def test_bts579891(self):
+        lex = utils.our_lex('realname "Paul \\"TBBle\\" Hampson"', posix=True)
+        option = lex.get_token()
+        self.assertEqual(option, 'realname')
+        realname = lex.get_token()
+        self.assertEqual(realname, 'Paul "TBBle" Hampson')
 
 
 class TestControl(unittest2.TestCase):
@@ -483,3 +570,28 @@ class TestMisc(unittest2.TestCase):
 
         isfirstrun = utils.first_run()
         self.assertIsNotNone(isfirstrun)
+
+    def test_exec_and_parse_bugscript(self):
+
+        handler = os.path.dirname(__file__) + '/../share/handle_bugscript'
+        bugscript_file = os.path.dirname(__file__) + '/data/bugscript'
+
+        (rc, h, ph, t, a) = utils.exec_and_parse_bugscript(handler, bugscript_file)
+
+        self.assertIn('python', t)
+        self.assertIn('debian', t)
+        self.assertIn('From: morph@dummy.int', h)
+        self.assertIn('User: morph@debian.org', ph)
+        self.assertIn('/etc/fstab', a)
+
+    def test_check_package_name(self):
+        self.assertTrue(utils.check_package_name('reportbug'))
+        self.assertTrue(utils.check_package_name('ab'))
+        self.assertFalse(utils.check_package_name('a'))
+        self.assertFalse(utils.check_package_name('.a'))
+        self.assertFalse(utils.check_package_name('dfffff       '))
+        self.assertFalse(utils.check_package_name('reportbug_reportbug'))
+        self.assertTrue(utils.check_package_name('reportbug+love-war.com'))
+        self.assertTrue(utils.check_package_name('reportbug2001'))
+        self.assertFalse(utils.check_package_name('UPPERCASE'))
+        self.assertFalse(utils.check_package_name('((()))'))
